So, welcome to my first ever **Python Project**! That is a game based on *Odd Even*, but with a twist of **Cricket!**
To install the Game, run `pip install OddEven-SP` in your Terminal.
Then to initiate the game, you need to run ```import OddEven-SP, OddEven-SP.start()```
Enjoy! Make sure to give FeedBack!